stoppingcriterion: Different options for the stopping criterion
Description
Different options for the stopping criterion
Usage
stoppingcriterion(ci, stopCI, stoppingoption = 2)
Value
Boolean answer if stopping criterion reached.
Arguments
ci
Confidence interval as tuple vector.
stopCI
Either a confidence interval for stoppingoption=1 and stoppingoption=2, or a scalar for stoppingoption=3.
stoppingoption
Option to determine if the stopping criterion is satisfied (1 for confidence interval included in stopCI, 2 for upper bound below or lower bound above stopCI, 3 for length restriction on confidence interval).